@@ -7,7 +7,7 @@
 """
 
 import requests
-from accio import logger
+from . import logger
 
 
 class Session(object):
